import java_cup.runtime.*;

%%

%class Lexer
%unicode
%cup
%line
%column


%{
  private Symbol symbol(int type) {
    return new Symbol(type, yyline, yycolumn);
  }
  private Symbol symbol(int type, Object value) {
    return new Symbol(type, yyline, yycolumn, value);
	
  }
%}

nl = \r|\n|\r\n
ws = [ \t]

%%
"+" {return symbol(sym.PIU);}
"-" {return symbol(sym.MEN);}
"*" {return symbol(sym.PER);}
"/" {return symbol(sym.DIV);}
"<" {return symbol(sym.MIN);}
">" {return symbol(sym.MAG);}
"<=" {return symbol(sym.MIN_UG);}
"=<" {return symbol(sym.UG_MIN);}
">=" {return symbol(sym.MAG_UG);}
"=>" {return symbol(sym.UG_MAG);}
"==" {return symbol(sym.UG_UG);}
"&" {return symbol(sym.AND);}
"|" {return symbol(sym.OR);}
"!" {return symbol(sym.NOT);}

"[" {return symbol(sym.QO);}
"]" {return symbol(sym.QC);}

"INT" {return symbol(sym.INT_TYPE);}
"DOUBLE" {return symbol(sym.DOUBLE_TYPE);}

PRINT {return symbol(sym.PRINT);}
GOTO {return symbol(sym.GOTO);}
GOTOF {return symbol(sym.GOTOF);}
GOTOT {return symbol(sym.GOTOT);}
EVAL {return symbol(sym.EVAL);}
ASS {return symbol(sym.ASS);}
END {return symbol(sym.END);}

L {return symbol(sym.LABEL, yytext());}
":" {return symbol(sym.DP);}

[a-z]* {return symbol(sym.ID, yytext());}
[1-9][0-9]*|0 {return symbol(sym.UINT, new Integer(yytext()));}
("+"|"-")?[1-9][0-9]*|0 {return symbol(sym.INT, new Integer(yytext()));}
("+"|"-")?[0-9]\.[0-9]* {return symbol(sym.DOUBLE, new Double(yytext()));}

"/*" ~ "*/" {;}

{ws}|{nl} {;}

